from urllib import unquote
from string import punctuation

from django.db import models
from django.utils.translation import ugettext_lazy as _

from mezzanine.pages.models import Page
from mezzanine.core.models import Orderable
from mezzanine.core.fields import FileField


class Slide(Orderable):
    """
    Allows for pretty banner images across the top of pages that will cycle
    through each other with a fade effect.
    """
    page = models.ForeignKey(Page, null=True, blank=True)
    target = models.URLField(null=True, blank=True)
    file = FileField(_('File'), max_length=200, upload_to='galleries', format='Image')
    title = models.TextField(_('Description'), blank=True)
    description = models.TextField(_('Description'), blank=True)

    class Meta:
        verbose_name = _('Slide')
        verbose_name_plural = _('Slides')
        ordering = ['_order']

    def __unicode__(self):
        return self.description

    def save(self, *args, **kwargs):
        """
        If no description is given when created, create one from the
        file name.
        """
        if not self.id and not self.description:
            name = unquote(self.file.url).split('/')[-1].rsplit('.', 1)[0]
            name = name.replace("'", '')
            name = ''.join([c if c not in punctuation else ' ' for c in name])
            # str.title() doesn't deal with unicode very well.
            # http://bugs.python.org/issue6412
            name = ''.join([s.upper() if i == 0 or name[i - 1] == ' ' else s
                            for i, s in enumerate(name)])
            self.description = name
        super(Slide, self).save(*args, **kwargs)




from copy import deepcopy

from django.contrib import admin

from mezzanine.pages.models import RichTextPage

from mezzanine.core.admin import TabularDynamicInlineAdmin
from mezzanine.pages.admin import PageAdmin
from mezzanine.forms.admin import FormAdmin
from mezzanine.galleries.admin import GalleryAdmin

try:
    from cartridge.shop.models import Category
    from cartridge.shop.admin import CategoryAdmin
    cartridge = True
except ImportError:
    cartridge = False

from .models import Slide


"""
We do what we do here instead of just attaching it to PageAdmin because more
things then just pages inherit PageAdmin and if we just inject it into PageAdmin
I've had some very bad things happen. Thus I inject it into each page type
individually in a way that best suits it.
"""


class SlideInline(TabularDynamicInlineAdmin):
    model = Slide


class RichTextPageAdmin(PageAdmin):
    inlines = (SlideInline,)

admin.site.unregister(RichTextPage)
admin.site.register(RichTextPage, RichTextPageAdmin)

FormAdmin.inlines += (SlideInline,)
GalleryAdmin.inlines += (SlideInline,)


if cartridge:
    class CategoryAdminInline(CategoryAdmin):
        inlines = (SlideInline,)

    admin.site.unregister(Category)
    admin.site.register(Category, CategoryAdminInline)



from setuptools import setup


setup(
    name='mezzanineHtmlSlides',
    version='0.1.2dev',
    license='Simplified BSD',

    install_requires = [
        'Mezzanine',
    ],

    description='Plug a html slideshow into your mezzanine website on all pages.',
    long_description=open('README.md').read(),

    author='Tonino Jankov',
    author_email='tyaakow@gmail.com',

    url='http://github.com/tjankov/mezzanineHtmlSlides',
    download_url='http://github.com/tjankov/mezzanineHtmlSlides/downloads',

    include_package_data=True,

    packages=['mezzaninehtmlslides'],

    zip_safe=False,
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ]
)
